@@ -1,10 +1,10 @@
 # onvif/services/deviceio.py
 
 from ..operator import ONVIFOperator
-from ..utils import ONVIFWSDL
+from ..utils import ONVIFWSDL, ONVIFService
 
 
-class DeviceIO:
+class DeviceIO(ONVIFService):
     def __init__(self, xaddr=None, **kwargs):
         # References:
         # - ONVIF Release 2.1 (June 2011) Split from Core 2.0
@@ -145,11 +145,11 @@ class DeviceIO:
             "GetSerialPortConfiguration", SerialPortToken=SerialPortToken
         )
 
-    def SetSerialPortConfiguration(self, SerialPortConfiguration, ForcePersistence):
+    def SetSerialPortConfiguration(self, SerialPortConfiguration, ForcePersistance):
         return self.operator.call(
             "SetSerialPortConfiguration",
             SerialPortConfiguration=SerialPortConfiguration,
-            ForcePersistence=ForcePersistence,
+            ForcePersistance=ForcePersistance,
         )
 
     def GetSerialPortConfigurationOptions(self, SerialPortToken):
