@@ -6,6 +6,7 @@ from .zeep import ZeepPatcher
 from .xml_capture import XMLCapturePlugin
 from .error_handlers import ONVIFErrorHandler
 from .discovery import ONVIFDiscovery
+from .service import ONVIFService
 
 
 __all__ = [
@@ -15,4 +16,5 @@ __all__ = [
     "XMLCapturePlugin",
     "ONVIFErrorHandler",
     "ONVIFDiscovery",
+    "ONVIFService",
 ]
